@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.1.9);
+  our $VERSION = qv(8.2.0);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -238,9 +238,11 @@ sub filter {
          $suffix .= "shift;"
        }
 
-      push @types, ($is_ext_class || $1 eq "__PACKAGE__") ? "Object" : $1;
-      push @defaults, $default;
-      push @vars, substr($2,1);
+       my $type = $is_ext_class ? "InstanceOf['$1']" : $1;
+       $type = "InstanceOf[__PACKAGE__]" if $1 eq "__PACKAGE__";
+       push @types, $type;
+       push @defaults, $default;
+       push @vars, substr($2,1);
 
       "$2$3$4" # drop the class/type info
     }gmse;
